@@ -2,6 +2,7 @@ package action
 
 import (
 	"os"
+	"runtime"
 	"testing"
 
 	"github.com/Masterminds/glide/msg"
@@ -11,7 +12,15 @@ func TestPlugin(t *testing.T) {
 	wd, _ := os.Getwd()
 	os.Chdir("../testdata/plugin")
 	msg.Default.PanicOnDie = true
-	cmd := "hello"
+	var cmd string
+
+	// Windows scripts for testing (batch) are different from shells scripts.
+	// Making sure the plugin works in both bases.
+	if runtime.GOOS == "windows" {
+		cmd = "hello-win"
+	} else {
+		cmd = "hello"
+	}
 	args := []string{"a", "b"}
 	// FIXME: Trapping the panic is the nice thing to do.
 	Plugin(cmd, args)
