@@ -515,7 +515,7 @@ func (r *Resolver) resolveImports(queue *list.List, testDeps, addTest bool) ([]s
 			if strings.HasPrefix(errStr, "no buildable Go source") {
 				msg.Debug("No subpackages declared. Skipping %s.", dep)
 				continue
-			} else if os.IsNotExist(err) && !foundErr && !foundQ {
+			} else if osDirNotFound(err, r.Handler.PkgPath(dep)) && !foundErr && !foundQ {
 				// If the location doesn't exist, there hasn't already been an
 				// error, it's not already been in the Q then try to fetch it.
 				// When there's an error or it's already in the Q (it should be
@@ -962,6 +962,21 @@ type PkgInfo struct {
 	Loc        PkgLoc
 }
 
+// PackagesAddedToStdlib is the list of packages added to the go standard lib
+// at various points.
+var PackagesAddedToStdlib = map[string]struct{}{
+	// context and net/http/httptrace are packages being added to
+	// the Go 1.7 standard library. Some packages, such as golang.org/x/net
+	// are importing it with build flags in files for go1.7.
+	"context":            struct{}{},
+	"net/http/httptrace": struct{}{},
+
+	// math.bits are packages being added to the Go 1.9 standard library.
+	// Some packages, such as github.com/RoaringBitmap/roaring are importing
+	// it with build flags in files for go1.9.
+	"math/bits": struct{}{},
+}
+
 // FindPkg takes a package name and attempts to find it on the filesystem
 //
 // The resulting PkgInfo will indicate where it was found.
@@ -1052,11 +1067,9 @@ func (r *Resolver) FindPkg(name string) *PkgInfo {
 		// https://blog.golang.org/the-app-engine-sdk-and-workspaces-gopath
 		info.Loc = LocAppengine
 		r.findCache[name] = info
-	} else if name == "context" || name == "net/http/httptrace" {
-		// context and net/http/httptrace are packages being added to
-		// the Go 1.7 standard library. Some packages, such as golang.org/x/net
-		// are importing it with build flags in files for go1.7. Need to detect
-		// this and handle it.
+	} else if _, ok := PackagesAddedToStdlib[name]; ok {
+		// Various packages are being added to the Go standard library, and being imported
+		// with build flags. Need to detect this and handle it.
 		info.Loc = LocGoroot
 		r.findCache[name] = info
 	}
@@ -1142,3 +1155,26 @@ func dedupeStrings(s1, s2 []string) (r []string) {
 
 	return
 }
+
+// In Go 1.9 go/build.ImportDir changed so that a missing dir
+// no longer responses with os.IsNotExist. Instead the error changed
+// one in the form of fmt.Errorf("cannot find package %q in:\n\t%s", path, p.Dir)
+// which is similar to other go/build.ImportDir errors. This function
+// attempts to detect when ImportDir thinks something is not found
+func osDirNotFound(err error, p string) bool {
+
+	if os.IsNotExist(err) {
+		return true
+	}
+
+	// Since there are multiple errors that start like this we need to make
+	// sure the directory is not present
+	if strings.HasPrefix(err.Error(), "cannot find package ") {
+		_, nferr := os.Stat(p)
+		if os.IsNotExist(nferr) {
+			return true
+		}
+	}
+
+	return false
+}
